@@ -61,7 +61,7 @@ $simnetwork @themereports @simtitles @reporttitles @simdata @retrievedata
 $target 
 ); # our @EXPORT = qw( );
 
-$VERSION = '0.40.11'; # our $VERSION = '';
+$VERSION = '0.40.13'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT it a tool for detailed metadesign. It manages parametric explorations through the ESP-r building performance simulation platform and performs optimization by block coordinate descent.';
 
 #################################################################################
@@ -384,7 +384,7 @@ sub calcmediumiters
 	my @varinumbers = @_;
 	my $countcase = 0;
 	my @mediumiters;
-	foreach (@varinumbers)
+	foreach ( @varinumbers )
 	{
 		my $countblock = 0;
 		foreach (keys %$_)
@@ -1041,6 +1041,9 @@ sub opt
 	# eval `cat $configfile`; # The file where the program data are
 	
 	require $configfile;
+	if ( not ( $outfile ) ) { $outfile = "$mypath/$file-$fileconfig-feedback.txt"; } 
+	if ( not ( $toshell ) ) { $toshell = "$mypath/$file-toshell.txt"; } 
+	
 	$tee = new IO::Tee(\*STDOUT, ">>$toshell"); # GLOBAL ZZZ
 
 #	if ($casefile) { eval `cat $casefile` or die; }
@@ -1108,8 +1111,8 @@ sub opt
 		#say "dump(\@varinumbers), " . dump(@varinumbers); #say "dumpBEFORE(\@miditers), " . dump(@miditers);
 	
 		calcoverlaps(@sweeps); # PRODUCES @calcoverlaps WHICH IS globsAL. ZZZ
-		
-		@mediumiters = calcmediumiters(@varinumbers); say $tee "BEGINNING dump!(\@mediumiters), " . dump(@mediumiters); # globsALS. ZZZ
+		say "VARINUMBERS: " . dump ( @varinumbers );
+		@mediumiters = calcmediumiters( @varinumbers ); say $tee "BEGINNING dump!(\@mediumiters), " . dump(@mediumiters); # globsALS. ZZZ
 		#$itersnum = getitersnum($countcase, $varinumber, @varinumbers); #say "\$itersnum OUT = $itersnum";
 		
 		@rootnames = definerootcases(\@sweeps, \@mediumiters); say $tee "BEGINNING \@rootnames " . dump(@rootnames); 
@@ -1149,9 +1152,9 @@ Sim::OPT.
 
 =head1 DESCRIPTION
 
-Sim::OPT is a tool for detailed metadesign of buildings. It morphs models by propagation of constraints through the ESP-r building performance simulation platform and performs optimization by overlapping block coordinate descent.
+Sim::OPT is a set of tools for detailed metadesign of buildings. The main module morphs models by propagation of constraints mainly through the ESP-r building performance simulation platform and performs optimization by overlapping block coordinate descent.
 
-A working knowledge of ESP-r (http://www.esru.strath.ac.uk/Programs/ESP-r.htm) is necessary to use OPT.
+A working knowledge of ESP-r (http://www.esru.strath.ac.uk/Programs/ESP-r.htm) is necessary to use most functionalitues of OPT. ESP-r must be compiled for text (not graphics) to be managed by OPT. It has only been tested on Linux.
 
 To install OPT, the command <cpanm Sim::OPT> has to be issued. Perl will install all dependencies. OPT can be loaded through the command <use Sim::OPT> in Perl. For that purpose, the batch file "opt" (which can be found packed in the "optw.tar.gz" file in "example" folder in this distribution) may be copied in a work directory and the command <opt> may be issued. That command will activate the OPT's functions, following the settings specified in a previously prepared configuration file. When launched, OPT will ask the path to that file. Its activity will start after receiving that information. 
 That file must contain a suitable description of the operations to be accomplished pointing to an existing ESP-r model.
